/*
 * Copyright (c) 2007 by Brian Marick.
 * Inspired by the Java version of the Hierarchical Data format, from the
 * University of Illinois NCSA and The HDF Group (http://www.hdfgroup.org/).
 * This code is intended for use only for training in test-driven design.
 * See LICENSE.txt
 */



package exampler.hdf.internal;

import java.nio.ByteOrder;

public class NumberDescription {
    private final String type;
    private final int sizeInBytes;
    private final ByteOrder byteOrder;

    public NumberDescription(String type, int sizeInBytes, ByteOrder byteOrder) {
        this.type = type;
        this.sizeInBytes = sizeInBytes;
        this.byteOrder = byteOrder;
    }


    public String getType() { return type; }
    public int getSizeInBytes() { return sizeInBytes; }
    public ByteOrder getByteOrder() { return byteOrder; }


    @SuppressWarnings({"RedundantIfStatement"})
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        NumberDescription that = (NumberDescription) o;

        if (sizeInBytes != that.sizeInBytes) return false;
        if (byteOrder != null ? !byteOrder.equals(that.byteOrder) : that.byteOrder != null) return false;
        if (type != null ? !type.equals(that.type) : that.type != null) return false;

        return true;
    }

    public int hashCode() {
        int result;
        result = (type != null ? type.hashCode() : 0);
        result = 31 * result + sizeInBytes;
        result = 31 * result + (byteOrder != null ? byteOrder.hashCode() : 0);
        return result;
    }

    public String toString() {
        return String.format("#{%s} size %d, %s", getType(), getSizeInBytes(), getByteOrder().toString());
    }

    public NumberDescription withoutByteOrder() {
        return new NumberDescription(type, sizeInBytes, null);
    }
}
