/*
 * Copyright (c) 2007 by Brian Marick.
 * Inspired by the Java version of the Hierarchical Data format, from the
 * University of Illinois NCSA and The HDF Group (http://www.hdfgroup.org/).
 * This code is intended for use only for training in test-driven design.
 * See LICENSE.txt
 */

package exampler.hdf.internal.converters;

import junit.framework.TestCase;
import exampler.hdf.CompoundDataset;
import exampler.hdf.internal.Like;

import java.nio.ByteBuffer;
import java.util.Arrays;

public class ConverterTest extends TestCase {

    public void test_members_can_be_created_from_raw_HDF_data() {
        Converter converter = Converter.of(Like.floating(4));
        assertEquals(CompoundDataset.FLOAT_TYPE, converter.getElementType());
        assertEquals(4, converter.getBytesPerElement());
    }

    public void test_members_can_be_created_from_java_datatypes() {
        Converter converter;

        converter = Converter.of(new int[] {1, 2, 3});
        assertEquals(CompoundDataset.INTEGER_TYPE, converter.getElementType());
        assertEquals(4, converter.getBytesPerElement());

        converter = Converter.of(new long[] {1, 2, 3});
        assertEquals(CompoundDataset.INTEGER_TYPE, converter.getElementType());
        assertEquals(8, converter.getBytesPerElement());

        converter = Converter.of(new float[] {1.0f, 2.0f });
        assertEquals(CompoundDataset.FLOAT_TYPE, converter.getElementType());
        assertEquals(4, converter.getBytesPerElement());

        converter = Converter.of(new double[] {1.0, 2.0 });
        assertEquals(CompoundDataset.FLOAT_TYPE, converter.getElementType());
        assertEquals(8, converter.getBytesPerElement());
    }


    public void test_members_can_extract_appropriate_data_from_byte_buffers() {
        int[] expected = new int[] { 1, 2, 3 };
        Converter converter = Converter.of(expected);

        byte[] rawbytes = new byte[] { 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3 };
        ByteBuffer buffer = ByteBuffer.wrap(rawbytes);
        int[] actual = (int[]) converter.convertToJavaFormat(buffer, expected.length);
        assertTrue(Arrays.equals(expected, actual));
    }
}
