/*
 * Copyright (c) 2007 by Brian Marick.
 * See LICENSE.txt
 */

package exampler.hdf.internal.diskAccess;

import exampler.hdf.internal.CompoundDatasetFAQ;
import exampler.hdf.internal.converters.Converter;
import exampler.hdf.testUtilities.TestFileUtils;

import java.nio.ByteOrder;
import java.util.Arrays;


public class PileOfBytesTest extends TestFileUtils implements CompoundDatasetFAQ {


    // Test writing from the perspective of a typical client class, which acts
    // as a FAQ about metadata.

    private final Object[] data = { new double[]{1.0, 2.5, 4.25},
                                    new int[]{0x80706050, 4, 2}};

    private final Converter[] converters = {Converter.of(data[0]), Converter.of(data[1])};



    public int tellHowManyMembers() { return converters.length; }
    public long tellMemberDimensions() { return ((double[])data[0]).length; }

    public String tellTypeOf(int member) {
        return converters[member].getElementType();
    }

    public int tellSizeInBytesOf(int member) {
        return converters[member].getBytesPerElement();
    }

    public ByteOrder tellByteOrderOf(int member) {
        return converters[member].getByteOrder();
    }



    // Here are the file-level details of I/O.
    // Hidden from user by H5CompoundDS.

    public void testTypicalReadingAndWriting() {

        PileLayout layout = PileLayout.createFrom(this);
        PileOfBytes output = PileOfBytes.openFileForWriting(tempFileName, layout);

        output.overwriteAsBytes(data[1], 1, converters[1]);
        output.overwriteAsBytes(data[0], 0, converters[0]);
        output.close();

        PileOfBytes input = PileOfBytes.openFileForReading(tempFileName);

        assertTrue(Arrays.equals((double[]) data[0],
                                 (double[]) input.createDataFromBytes(0, converters[0])));

        assertTrue(Arrays.equals((int[]) data[1],
                                 (int[]) input.createDataFromBytes(1, converters[1])));

        input.close();
    }

}
